@@ -13,7 +13,7 @@
 import uuid
 
 import fixtures
-import six
+from unittest import mock
 
 from keystonemiddleware.auth_token import _cache
 from keystonemiddleware.auth_token import _exceptions as exc
@@ -114,7 +114,7 @@ class TestLiveMemcache(base.BaseAuthTokenTestCase):
             'memcache_secret_key': 'mysecret'
         }
 
-        token = six.b(uuid.uuid4().hex)
+        token = uuid.uuid4().hex.encode()
         data = uuid.uuid4().hex
 
         token_cache = self.create_simple_middleware(conf=conf)._token_cache
@@ -123,6 +123,25 @@ class TestLiveMemcache(base.BaseAuthTokenTestCase):
         token_cache.set(token, data)
         self.assertEqual(token_cache.get(token), data)
 
+    @mock.patch("keystonemiddleware.auth_token._memcache_crypt.unprotect_data")
+    def test_corrupted_cache_data(self, mocked_decrypt_data):
+        mocked_decrypt_data.side_effect = Exception("corrupted")
+
+        conf = {
+            'memcached_servers': ','.join(MEMCACHED_SERVERS),
+            'memcache_security_strategy': 'encrypt',
+            'memcache_secret_key': 'mysecret'
+        }
+
+        token = uuid.uuid4().hex.encode()
+        data = uuid.uuid4().hex
+
+        token_cache = self.create_simple_middleware(conf=conf)._token_cache
+        token_cache.initialize({})
+
+        token_cache.set(token, data)
+        self.assertIsNone(token_cache.get(token))
+
     def test_sign_cache_data(self):
         conf = {
             'memcached_servers': ','.join(MEMCACHED_SERVERS),
@@ -130,7 +149,7 @@ class TestLiveMemcache(base.BaseAuthTokenTestCase):
             'memcache_secret_key': 'mysecret'
         }
 
-        token = six.b(uuid.uuid4().hex)
+        token = uuid.uuid4().hex.encode()
         data = uuid.uuid4().hex
 
         token_cache = self.create_simple_middleware(conf=conf)._token_cache
@@ -145,7 +164,7 @@ class TestLiveMemcache(base.BaseAuthTokenTestCase):
             'memcache_secret_key': 'mysecret'
         }
 
-        token = six.b(uuid.uuid4().hex)
+        token = uuid.uuid4().hex.encode()
         data = uuid.uuid4().hex
 
         token_cache = self.create_simple_middleware(conf=conf)._token_cache
@@ -159,7 +178,7 @@ class TestLiveMemcache(base.BaseAuthTokenTestCase):
             'memcache_use_advanced_pool': True
         }
 
-        token = six.b(uuid.uuid4().hex)
+        token = uuid.uuid4().hex.encode()
         data = uuid.uuid4().hex
 
         token_cache = self.create_simple_middleware(conf=conf)._token_cache
