@@ -33,8 +33,10 @@ class OptsTestCase(utils.TestCase):
         expected_opt_names = [
             'auth_admin_prefix',
             'auth_host',
+            'interface',
             'auth_port',
             'auth_protocol',
+            'www_authenticate_uri',
             'auth_uri',
             'identity_uri',
             'auth_version',
@@ -51,10 +53,8 @@ class OptsTestCase(utils.TestCase):
             'cafile',
             'region_name',
             'insecure',
-            'signing_dir',
             'memcached_servers',
             'token_cache_time',
-            'revocation_cache_time',
             'memcache_security_strategy',
             'memcache_secret_key',
             'memcache_use_advanced_pool',
@@ -63,12 +63,16 @@ class OptsTestCase(utils.TestCase):
             'memcache_pool_unused_timeout',
             'memcache_pool_conn_get_timeout',
             'memcache_pool_socket_timeout',
+            'memcache_sasl_enabled',
+            'memcache_username',
+            'memcache_password',
             'include_service_catalog',
             'enforce_token_bind',
-            'check_revocations_for_cached',
-            'hash_algorithms',
             'auth_type',
             'auth_section',
+            'service_token_roles',
+            'service_token_roles_required',
+            'service_type',
         ]
         opt_names = [o.name for (g, l) in result_of_old_opts for o in l]
         self.assertThat(opt_names, matchers.HasLength(len(expected_opt_names)))
@@ -84,6 +88,8 @@ class OptsTestCase(utils.TestCase):
 
         # This is the sample config generator list WITHOUT deprecations
         expected_opt_names = [
+            'www_authenticate_uri',
+            'interface',
             'auth_uri',
             'auth_version',
             'delay_auth_decision',
@@ -95,10 +101,8 @@ class OptsTestCase(utils.TestCase):
             'cafile',
             'region_name',
             'insecure',
-            'signing_dir',
             'memcached_servers',
             'token_cache_time',
-            'revocation_cache_time',
             'memcache_security_strategy',
             'memcache_secret_key',
             'memcache_use_advanced_pool',
@@ -107,12 +111,16 @@ class OptsTestCase(utils.TestCase):
             'memcache_pool_unused_timeout',
             'memcache_pool_conn_get_timeout',
             'memcache_pool_socket_timeout',
+            'memcache_sasl_enabled',
+            'memcache_username',
+            'memcache_password',
             'include_service_catalog',
             'enforce_token_bind',
-            'check_revocations_for_cached',
-            'hash_algorithms',
             'auth_type',
             'auth_section',
+            'service_token_roles',
+            'service_token_roles_required',
+            'service_type',
         ]
         opt_names = [o.name for (g, l) in result for o in l]
         self.assertThat(opt_names, matchers.HasLength(len(expected_opt_names)))
